 SELECT
    g.id,
    g.name,
    g.edition,
    (SELECT name FROM Platform p WHERE p.id = g.platform_id) AS 'platform',
    date(g.created_on) AS 'added_on',
    date(g.release_date) AS 'release_date',
    g.description_short,
    CASE WHEN (LENGTH(g.description) > 500) THEN SUBSTR(g.description, 0, 500) || '...' WHEN LENGTH(g.description) <= 500 THEN g.description END AS 'description',
    g.user_rating,
    g.region_id 'region',
    g.difficulty,
    (SELECT GROUP_CONCAT(name, ', ') FROM (SELECT name FROM Label l JOIN GameLabel gl ON l.id = gl.label_id AND gl.game_id = g.id ORDER BY name)) AS 'labels',
    (SELECT GROUP_CONCAT(name, ', ') FROM (SELECT name FROM Genre ge JOIN GameGenre gg ON ge.id = gg.genre_id AND gg.game_id = g.id ORDER BY name)) AS 'genres',
    (SELECT GROUP_CONCAT(name, ', ') FROM (SELECT name FROM Franchise f JOIN GameFranchise gf ON f.id = gf.franchise_id AND gf.game_id = g.id ORDER BY name)) AS 'franchises',
    (SELECT GROUP_CONCAT(name, ', ') FROM (SELECT name FROM Developer d JOIN GameDeveloper gd ON d.id = gd.developer_id AND gd.game_id = g.id ORDER BY name)) AS 'developers',
    (SELECT GROUP_CONCAT(name, ', ') FROM (SELECT name FROM Publisher p JOIN GamePublisher gp ON p.id = gp.publisher_id AND gp.game_id = g.id ORDER BY name)) AS 'publishers',
    (SELECT GROUP_CONCAT(full_name, ', ') FROM (SELECT name || ' ' || first_name 'full_name' FROM Friend f JOIN GameLoan gl ON f.id = gl.friend_id AND gl.game_id = g.id AND gl.end_of_loan is NULL ORDER BY name)) AS 'loan',
    (SELECT GROUP_CONCAT(name, ', ') FROM (SELECT name FROM GameDLC gd WHERE gd.game_id = g.id)) AS 'dlc',
    (SELECT GROUP_CONCAT(name, ', ') FROM (SELECT name FROM GameMOD gm WHERE gm.game_id = g.id)) AS 'mod',
    g.notes,
    g.notes_con,
    g.notes_pro,
    g.playtime AS 'playtime_minutes',
    g.mc_score,
    g.hltb_main_story,
    date(g.purchased_date) AS 'purchased_on',
    CASE WHEN (g.purchased_price < 0) THEN 0 ELSE g.purchased_price END AS 'purchased_price',
    CASE WHEN (g.sell_price < 0) THEN 0 ELSE g.sell_price END AS 'sell_price',
    g.collector_has_box,
    g.collector_has_disc_or_card,
    g.collector_has_digital,
    g.collector_has_manual,
    g.collector_has_other,
    g.collector_has_text,
    g.collector_is_complete_in_box,
    g.collector_is_sealed,
    CASE WHEN (g.player_info_single_player_has == 1) THEN 'Yes' ELSE 'No' END AS 'single_player',
    CASE WHEN (g.player_info_single_player_has_non_story == 1) THEN 'Yes' ELSE 'No' END AS 'single_player_non_story',
    CASE WHEN (g.player_info_local_alternating == 1) THEN 'Yes' ELSE 'No' END AS 'local_alternating',
    g.player_info_local_alternating_max,
    g.player_info_local_alternating_min,
    CASE WHEN (g.player_info_local_coop_non_story_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'local_coop_non_story',
    g.player_info_local_coop_non_story_mode_max,
    g.player_info_local_coop_non_story_mode_min,
    CASE WHEN (g.player_info_local_coop_story_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'local_coop_story',
    g.player_info_local_coop_story_mode_max,
    g.player_info_local_coop_story_mode_min,
    CASE WHEN (g.player_info_local_team_versus_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'local_team_versus',
    g.player_info_local_team_versus_mode_max,
    g.player_info_local_team_versus_mode_min,
    CASE WHEN (g.player_info_local_versus_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'local_versus',
    g.player_info_local_versus_mode_max,
    g.player_info_local_versus_mode_min,
    CASE WHEN (g.player_info_lan_coop_non_story_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'lan_coop_non_story',
    g.player_info_lan_coop_non_story_mode_max,
    g.player_info_lan_coop_non_story_mode_min,
    CASE WHEN (g.player_info_lan_coop_story_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'lan_coop_story',
    g.player_info_lan_coop_story_mode_max,
    g.player_info_lan_coop_story_mode_min,
    CASE WHEN (g.player_info_lan_team_versus_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'lan_team_versus',
    g.player_info_lan_team_versus_mode_max,
    g.player_info_lan_team_versus_mode_min,
    CASE WHEN (g.player_info_lan_versus_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'lan_versus',
    g.player_info_lan_versus_mode_max,
    g.player_info_lan_versus_mode_min,
    CASE WHEN (g.player_info_online_coop_non_story_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'online_coop_non_story',
    g.player_info_online_coop_non_story_mode_max,
    g.player_info_online_coop_non_story_mode_min,
    CASE WHEN (g.player_info_online_coop_story_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'online_coop_story',
    g.player_info_online_coop_story_mode_max,
    g.player_info_online_coop_story_mode_min,
    CASE WHEN (g.player_info_online_team_versus_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'online_team_versus',
    g.player_info_online_team_versus_mode_max,
    g.player_info_online_team_versus_mode_min,
    CASE WHEN (g.player_info_online_versus_mode_has == 1) THEN 'Yes' ELSE 'No' END AS 'online_versus',
    g.player_info_online_versus_mode_max,
    g.player_info_online_versus_mode_min,
    g.loose_price,
    g.complete_price

 FROM Game g
 %s

 ORDER BY g.name, g.edition
